{#
    basic/search.html
    ~~~~~~~~~~~~~~~~~

    Template for the search page.

    :copyright: Copyright 2007-2013 by the Sphinx team, see AUTHORS.
    :license: BSD, see LICENSE for details.
#}
{%- extends "layout.html" %}
{% set title = _('Search') %}

{% block extra_head %}
  <script type="text/javascript">
    jQuery(function() { Search.loadIndex("{{ pathto('searchindex.js', 1) }}"); });
  </script>
{% endblock %}

{% block body %}
  <h1 id="search-documentation">{{ _('Search') }}</h1>
  <noscript>
    <div id="fallback" class="admonition warning">
    <p>
      {% trans %}Please activate JavaScript to enable the search
      functionality.{% endtrans %}
    </p>
    </div>
  </noscript>
  <p>
    {% trans %}From here you can search these documents. Enter your search
    words into the box below and click "search". Note that the search
    function will automatically search for all of the words. Pages
    containing fewer words won't appear in the result list.{% endtrans %}
  </p>

  <form class="form-search" action="" method="get">
    <input type="text" name="q" class="input-medium search-query" placeholder="Search documentation...">
    <button type="submit" class="btn btn-primary">{{ _('search') }}</button>
    <!-- <span id="search-progress" style="padding-left: 10px"></span> -->
  </form>

  {% if search_performed %}
    <h2>{{ _('Search Results') }}</h2>
    {% if not search_results %}
      <p>{{ _('Your search did not match any results.') }}</p>
    {% endif %}
  {% endif %}
  <div id="search-results">
  {% if search_results %}
    <ul>
    {% for href, caption, context in search_results %}
      <li class="card">
        <div class="card-block">
          <h3 class="card-title"><a href="{{ pathto(item.href) }}">{{ caption }}</a></h3>
          <div class="context">{{ context|e }}</div>
        </div>
      </li>
    {% endfor %}
    </ul>
  {% endif %}
  </div>
{% endblock %}
