<li class="dropdown globaltoc-container">
  <a href="{{ pathto(master_doc) }}"
     class="dropdown-toggle"
     data-toggle="dropdown"><i class="fa fa-home"></i> {%- if theme_navbar_site_name %}{{ theme_navbar_site_name }}{%- else %}{{ project|e }}{% endif %} {%- if version %}({{ version|e }}){%- endif %} <b class="caret"></b></a>
  <ul class="dropdown-menu globaltoc"
    >{{ toctree(maxdepth=theme_globaltoc_depth|toint, collapse=False, includehidden=theme_globaltoc_includehidden|tobool) }}</ul>
</li>
